<?php
/**
 * Plugin Filehtml (addon for plugin Adm_redacteurs)
 * Version  : 1.4 (2018/04/12)
 * Compatibility : Guppy v5.0+ et Adm_redacteurs v6.12+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require ADMR_CORE_PATH.'/admin_controller.php';

class Admin_check_filehtml_data_integrity_controller extends Admin_controller
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $_lang = array();         // Données de langue
    protected $_config = array();       // Données de configuration
//    protected $_params = array();       // Données récupérés par post ou get
//    protected $_sort_options = array();	// Options de tri    
  
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    function __construct()
    {
        parent :: __construct();       
        
        $this -> load_helper('url_helper');
        $this -> load_helper('var_helper');
        $this -> load_helper('security_helper');
        $this -> load_helper('file_helper');
        
        $this -> load_addon_helper('filehtml', 'plugin_menu_for_filehtml_helper');
        $this -> load_addon_helper('filehtml', 'filehtml_infos_helper');
        
        $this -> load_addon_model('filehtml', 'filehtml_ids_model');
        $this -> load_addon_model('filehtml', 'filehtml_params_model');
        $this -> load_addon_model('filehtml', 'filehtml_counters_model');
        $this -> load_addon_model('filehtml', 'filehtml_menuitems_model');
        
        $this -> load_model('guppy_docid_model'); // Model des documents de guppy
        $this -> load_model('guppy_doc_model'); // Model des documents de guppy
        $this -> load_model('menuitems_model'); // Model des items de menus
        
        $this -> load_addon_lang('filehtml');
        $this -> load_addon_config('filehtml');        

        $this -> _lang = $this -> get_lang();
        $this -> _config = $this -> get_config();
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

    public function index()
    {        
        $this -> check_integrity();
    }

	// --------------------------------------------------------------------

    public function check_integrity()
    {
        set_time_limit(0);
        
        /**
         * Maintenance des données
         */
        $action = Var_helper :: import('action', 'post', 0, array(), array(array('Var_helper', 'is_alpha_num_dash')));
        $ids = Var_helper :: import('ids', 'post', array(), array(), array(array('Var_helper', 'is_digit')));
        $choice = Var_helper :: import('choice', 'post', 0, array(), array(array('Var_helper', 'is_digit')));
        
        $token_name = 'ADMR_check_data_integrity';
        $token_time_expire = $this -> _config['token_time_expire'];
        $referer = ADMR_SITE_URL.'admin/'.ADMR_BASE_HREF_PLUGIN.'&ctrl='.ADMR_CONTROLLER;
        $message = '';
        
        if (!empty($_POST) && Security_helper :: check_token($token_time_expire, $referer, $token_name) ) {            
 
            if ($action == 'filehtml') {  // Maintenance des données des documents           
                if ($choice == 1) {
                    $this -> _check_filehtml_integrity();
                } elseif ($choice == 2 && !empty($ids)) {
                    $this -> _check_filehtml_integrity($ids);    
                }
                               
                $message = ucfirst(sprintf($this -> _lang['the(m)_%s_succeeded'], $this -> _lang['control_of_integrity_of_filehtml_data']));
            }
            else if ($action == 'menuitem') { // Maintenance des données des items de menu associés aux documents
                if ($choice == 1) {
                    $this -> _check_filehtml_menuitems_integrity();
                } elseif ($choice == 2 && !empty($ids)) {
                    $this -> _check_filehtml_menuitems_integrity($ids);    
                }
                $message = ucfirst(sprintf($this -> _lang['the(m)_%s_succeeded'], $this -> _lang['control_of_integrity_of_filehtml_menuitems']));
            }
        }     
        //

        $data = array(
            'message' => $message,
            'lang' => $this -> _lang,
            'form_uri' => ADMR_BASE_HREF_PLUGIN.'&amp;ctrl='.ADMR_CONTROLLER,
            'token' => Security_helper :: create_token($token_name),
            'filehtmls' => $this -> _get_filehtmls(),
            'menuitems' => $this -> _get_filehtml_menuitems(),
            'action' => $action,
            'ids' => $ids,
            'choice' => $choice
        );

        parent :: render_page(str_replace(ADMR_PUBLIC_ROOT_PATH, '..', FILEHTML_VIEWS_PATH).'/check_filehtml_data_integrity', $data);
    }
        
	// --------------------------------------------------------------------

	/**
	 * Contrôle l'intégrité les données du fichier filehtml_ids.dtb
     * 
     * @access private
     * @param array Tableau contenant les identifiants des documents à contrôler (tous par défaut)
	 * @return void
	 */
    private function _check_filehtml_integrity($filehtml_ids = array())
    {
        $this -> _check_filehtml_ids_integrity($filehtml_ids);
        $this -> _check_filehtml_params_integrity();
        $this -> _check_filehtml_counters_integrity();
        
        return TRUE;
    }
        
	// --------------------------------------------------------------------

	/**
	 * Contrôle l'intégrité les données du fichier filehtml_ids.dtb
     * 
     * @access private
     * @param array Tableau contenant les identifiants des documents à contrôler (tous par défaut)
	 * @return void
	 */
    private function _check_filehtml_ids_integrity($filehtml_ids = array())
    {
        settype($filehtml_ids, 'array');
        
        if (empty($filehtml_ids)) {
            $filehtml_ids = array_keys($this -> filehtml_ids_model -> get());    
        }

        $filehtml_to_delete = array();
        
        foreach($filehtml_ids as $filehtml_id) {
            if ($this -> filehtml_params_model -> file_exists($filehtml_id) === FALSE) {
                $filehtml_to_delete[] = $filehtml_id;
            }
        }
        
        $this -> filehtml_ids_model -> delete_by_id($filehtml_to_delete);    
        
        return TRUE;
    }
        
	// --------------------------------------------------------------------

	/**
	 * Contrôle l'intégrité des fichiers filehtml_params_XX.inc
     * 
     * @access private
	 * @return void
	 */
    private function _check_filehtml_params_integrity()
    {
        $filehtml_missing = array();
        $filehtml_params_ids = $this -> filehtml_params_model -> get_files_ids();
        
        foreach($filehtml_params_ids as $filehtml_id) {
            $filehtml = $this -> filehtml_ids_model -> get_by_id($filehtml_id);
            
            if (empty($filehtml)) {
                $filehtml_missing[] = array_merge($this -> filehtml_params_model -> read($filehtml_id), array('status' => 'i', 'mode' => 2));                        
            }
        }
        
        $this -> filehtml_ids_model -> update_many($filehtml_missing);
        
        return TRUE;            
    }
        
	// --------------------------------------------------------------------

	/**
	 * Contrôle l'intégrité des compteurs des fichiers filehtml_counter_XX.inc
     * 
     * @access private
	 * @return void
	 */
    private function _check_filehtml_counters_integrity()
    {
        $filehtml_counters_to_delete = array();
        $filehtml_counters_ids = $this -> filehtml_counters_model -> get_files_ids();
        
        foreach($filehtml_counters_ids as $filehtml_id) {
            $filehtml = $this -> filehtml_ids_model -> get_by_id($filehtml_id);
            
            if (empty($filehtml)) {
                $filehtml_counters_to_delete[] = $filehtml_id;                        
            }
        }

        $this -> filehtml_counters_model -> delete_by_id($filehtml_counters_to_delete);
        
        return TRUE;            
    }
         
	// --------------------------------------------------------------------

	/**
	 * Contrôle l'intégrité les données des items de menu associés aux fichiers html
     * 
     * @access private
     * @param array Tableau contenant les identifiants des documents à contrôler (tous par défaut)
	 * @return void
	 */
    private function _check_filehtml_menuitems_integrity($filehtml_ids = array())
    {
        settype($filehtml_ids, 'array');        
        
        $filehtml_menuitems = $this -> filehtml_menuitems_model -> get(array('id_filehtml' => $filehtml_ids));

        foreach($filehtml_menuitems as $menuitem) {
            $menuitem += $this -> menuitems_model -> read($menuitem['id_menuitem']); 
            
            $filehtml_id = $this -> menuitems_model -> extract_doc_id_from_item_url($menuitem['url1']);
            $filehtml = $this -> filehtml_ids_model -> get(array('id' => $filehtml_id));
           
            if (strpos($menuitem['url1'], FILEHTML_PUBLIC_FILE_PATH) !== 0 || empty($filehtml)) {
                $this -> filehtml_menuitems_model -> delete_by_menuitem_id($menuitem['id_menuitem']);  
            }
        }
        
        return TRUE;
    }

	// --------------------------------------------------------------------

	/**
	 * récupère tous les documents filehtml enregistrés 
     * 
     * @access private
	 * @return array
	 */	
    private function _get_filehtmls()
    {
        return $this -> filehtml_ids_model -> get();
    }

	// --------------------------------------------------------------------

	/**
	 * récupère tous les items de menu enregistrés associés aux documents filehtml
     * 
     * @access private
	 * @return array
	 */	
    private function _get_filehtml_menuitems()
    {
        $filehtmls = array();
        $filehtml_menuitems = $this -> filehtml_menuitems_model -> get();
        
        foreach($filehtml_menuitems as $item) {
            $filehtmls[$item['id_filehtml']] = array_merge($item, $this -> filehtml_ids_model -> get_by_id($item['id_filehtml']));   
        }
        
        return $filehtmls;
    }

	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
/*    protected function set_params()
    {
        $this -> _params = parent :: set_params();
    }
*/    
	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['check_plugin_data_integrity']);
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    protected function _set_infos_page_content()
    {		
        return $this -> _lang['infos_page_check_plugin_data_integrity'];
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie des ajouts (js, css, code php) dans la partie <head> de la page 
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    public function set_header_addons()
    {
        $parent_addons = parent :: set_header_addons();
        
        $js = '';
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/waiting_process.js"></script>'."\n";
      
        $css = '';
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/form_validator.css" />'."\n";
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/waiting_process.css" />'."\n";
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/check_plugin_data_integrity.css" />'."\n";
 
        return $parent_addons.$js.$css;
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu du plugin qui est affiché en haut de la page
     *
     * @return array
     */
    protected function _set_menu_plugin_items()
    {
        return Plugin_menu_for_filehtml_helper :: set_admin_items('filehtml', $this -> _lang, $this -> _config, $this -> _admin_rights);
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu des informations du plugin qui sont affichées en bas de la page
     *
     * @return array Tableau contenant les informations du plugin sous la forme array('version' => , 'licence' => )
     */
    protected function _set_infos_plugin()
    {
        return Filehtml_infos_helper :: set_plugin_infos($this -> _lang);
    }

	// --------------------------------------------------------------------

} //End of Class